Programs in this directory
==========================

The programs here are used to test pySlip and to demonstrate some of the
capabilities of the widget:

=======================  =======
Program                  Details
=======================  =======
pyslip_demo.py           demonstrates some capabilities of pySlip
test_image_placement.py  allows playing with image placement
test_point_placement.py  allows playing with point placement
test_poly_placement.py   allows playing with polygon placement
test_text_placement.py   allows playing with text placement
test_gotoposition.py     test the "goto position" code
test_assumptions.py      test some assumptions made in pySlip
test_gmt_local_tiles.py  simplistic test of GMT tiles
test_osm_tiles.py        simplistic test of OSM tiles
test_maprel_image.py     simple test of map-relative image placement
test_maprel_poly.py      simple test of map-relative polygon placement
test_maprel_text.py      simple test of map-relative text placement
test_viewrel_image.py    simple test of view-relative image placement
test_viewrel_point.py    simple test of view-relative point placement
test_viewrel_poly.py     simple test of view-relative polygon placement
test_viewrel_text.py     simple test of view-relative text placement
=======================  =======

Other things here:

=======================  =======
Directory                What it is
=======================  =======
gmt_tiles.tar.gz         pre-generated GMT tiles
graphics                 graphics files used by the programs here
=======================  =======
